/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import {
  ALERT_DURATION,
  ALERT_END,
  ALERT_INSTANCE_ID,
  ALERT_SEVERITY,
  ALERT_RULE_TYPE_ID,
  ALERT_START,
  ALERT_STATUS,
  ALERT_UUID,
  ALERT_RULE_UUID,
  ALERT_RULE_NAME,
  ALERT_RULE_CATEGORY,
  ALERT_RULE_PRODUCER,
} from '@kbn/rule-data-utils/technical_field_names';
import {
  ALERT_STATUS_ACTIVE,
  ALERT_STATUS_RECOVERED,
} from '@kbn/rule-data-utils/alerts_as_data_status';

export const apmAlertResponseExample = [
  {
    [ALERT_RULE_TYPE_ID]: ['apm.error_rate'],
    'service.name': ['opbeans-java'],
    [ALERT_RULE_NAME]: ['Error count threshold | opbeans-java (smith test)'],
    [ALERT_DURATION]: [180057000],
    [ALERT_STATUS]: [ALERT_STATUS_ACTIVE],
    [ALERT_SEVERITY]: ['warning'],
    tags: ['apm', 'service.name:opbeans-java'],
    [ALERT_UUID]: ['0175ec0a-a3b1-4d41-b557-e21c2d024352'],
    [ALERT_RULE_UUID]: ['474920d0-93e9-11eb-ac86-0b455460de81'],
    'event.action': ['active'],
    '@timestamp': ['2021-04-12T13:53:49.550Z'],
    [ALERT_INSTANCE_ID]: ['apm.error_rate_opbeans-java_production'],
    [ALERT_START]: ['2021-04-12T13:50:49.493Z'],
    [ALERT_RULE_PRODUCER]: ['apm'],
    'event.kind': ['state'],
    [ALERT_RULE_CATEGORY]: ['Error count threshold'],
    'service.environment': ['production'],
    'processor.event': ['error'],
  },
  {
    [ALERT_RULE_TYPE_ID]: ['apm.error_rate'],
    'service.name': ['opbeans-java'],
    [ALERT_RULE_NAME]: ['Error count threshold | opbeans-java (smith test)'],
    [ALERT_DURATION]: [2419005000],
    [ALERT_END]: ['2021-04-12T13:49:49.446Z'],
    [ALERT_STATUS]: [ALERT_STATUS_RECOVERED],
    tags: ['apm', 'service.name:opbeans-java'],
    [ALERT_UUID]: ['32b940e1-3809-4c12-8eee-f027cbb385e2'],
    [ALERT_RULE_UUID]: ['474920d0-93e9-11eb-ac86-0b455460de81'],
    'event.action': ['close'],
    '@timestamp': ['2021-04-12T13:49:49.446Z'],
    [ALERT_INSTANCE_ID]: ['apm.error_rate_opbeans-java_production'],
    [ALERT_START]: ['2021-04-12T13:09:30.441Z'],
    [ALERT_RULE_PRODUCER]: ['apm'],
    'event.kind': ['state'],
    [ALERT_RULE_CATEGORY]: ['Error count threshold'],
    'service.environment': ['production'],
    'processor.event': ['error'],
  },
];

export const dynamicIndexPattern = {
  fields: [
    {
      name: '@timestamp',
      type: 'date',
      esTypes: ['date'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'event.action',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'event.kind',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'host.name',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_DURATION,
      type: 'number',
      esTypes: ['long'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_END,
      type: 'date',
      esTypes: ['date'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_INSTANCE_ID,
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_SEVERITY,
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_START,
      type: 'date',
      esTypes: ['date'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_STATUS,
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: ALERT_UUID,
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: [ALERT_RULE_PRODUCER],
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'processor.event',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: [ALERT_RULE_CATEGORY],
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: [ALERT_RULE_TYPE_ID],
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: [ALERT_RULE_NAME],
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: [ALERT_RULE_UUID],
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'service.environment',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'service.name',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'tags',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
    {
      name: 'transaction.type',
      type: 'string',
      esTypes: ['keyword'],
      searchable: true,
      aggregatable: true,
      readFromDocValues: true,
    },
  ],
  timeFieldName: '@timestamp',
  title: '.kibana_smith-alerts-observability*',
};
